gstools.covmodel
================

.. automodule:: gstools.covmodel

.. raw:: latex

    \clearpage

.. toctree::
   :hidden:

   covmodel.base.rst
   covmodel.models.rst
   covmodel.tpl_models.rst
   covmodel.plot.rst
